==> piwigo-2.1.3.tbz: www/piwigo/plugins/LocalFilesEditor/language/fr_FR/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Configuration locale';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Templates';
$lang['locfiledit_onglet_lang'] = 'Langues';
$lang['locfiledit_onglet_plug'] = 'Plugin Personnel';
$lang['locfiledit_cant_save'] = 'Impossible d\'écrire le fichier. Vérifiez les permissions (chmod) du dossier "include/".';
$lang['locfiledit_newfile'] = 'Le fichier n\'existe pas et sera créé lors de l\'enregistrement par LocalFiles Editor';
$lang['locfiledit_save_config'] = 'Le fichier a été enregistré.';
$lang['locfiledit_show_default'] = 'Afficher le fichier ';
$lang['locfiledit_save_bak'] = 'Une copie de sauvegarde du fichier sera créée lors de l\'enregistrement';
$lang['locfiledit_saved_bak'] = 'Une copie de sauvegarde a été créée (%s)';
$lang['locfiledit_save_file'] = 'Enregistrer le fichier';
$lang['locfiledit_choose_file'] = 'Choisissez un fichier à éditer';
$lang['locfiledit_edit'] = 'Editer';
$lang['locfiledit_restore'] = 'Charger le fichier de sauvegarde';
$lang['locfiledit_restore_confirm'] = 'Souaitez-vous charger le fichier de sauvegarde?
Vous devrez ensuite cliquer sur Enregistrer pour le restaurer.';
$lang['locfiledit_bak_loaded1'] = 'Fichier de sauvegarde chargé';
$lang['locfiledit_bak_loaded2'] = 'Vous devez l\'enregistrer pour le sauvegarder.';
$lang['locfiledit_syntax_error'] = 'Erreur de syntaxe! Impossible d\'enregistrer le fichier.';
$lang['locfiledit_enable_editarea'] = 'Activer Editarea';
$lang['locfiledit_disable_editarea'] = 'Désactiver Editarea';
$lang['locfiledit_new_tpl'] = 'Créer un nouveau fichier';
$lang['locfiledit_new_filename'] = 'Nom du fichier';
$lang['locfiledit_model'] = 'Modèle';
$lang['locfiledit_empty_page'] = 'Page vierge';
$lang['locfiledit_parent_directory'] = 'Dossier parent';
$lang['locfiledit_filename_error'] = 'Caractères interdits dans le nom du fichier.';
$lang['locfiledit_file_already_exists'] = 'Le fichier existe déjà.';
$lang['locfiledit_model_error'] = 'Veuillez sélectionner un modèle.';
$lang['locfiledit_empty_filename'] = 'Veuillez indiquer un nom de fichier.';
$lang['locfiledit_webmaster_only'] = 'Seuls les webmasters sont autorisés à créer ou modifier les fichiers locaux.';

?>

==> piwigo-2.3.3.tbz: www/piwigo/plugins/LocalFilesEditor/language/fr_FR/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Configuration locale';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Templates';
$lang['locfiledit_onglet_lang'] = 'Langues';
$lang['locfiledit_onglet_plug'] = 'Plugin Personnel';
$lang['locfiledit_cant_save'] = 'Impossible d\'écrire le fichier. Vérifiez les permissions (chmod) du dossier "local/".';
$lang['locfiledit_newfile'] = 'Dans cette fenêtre, écrivez les informations pour configurer votre galerie Piwigo.';
$lang['locfiledit_save_config'] = 'Le fichier a été enregistré.';
$lang['locfiledit_show_default'] = 'Afficher le fichier ';
$lang['locfiledit_save_bak'] = 'Une copie de sauvegarde du fichier sera créée lors de l\'enregistrement';
$lang['locfiledit_saved_bak'] = 'Une copie de sauvegarde a été créée (%s)';
$lang['locfiledit_save_file'] = 'Enregistrer le fichier';
$lang['locfiledit_choose_file'] = 'Choisissez un fichier à éditer';
$lang['locfiledit_edit'] = 'Editer';
$lang['locfiledit_restore'] = 'Charger le fichier de sauvegarde';
$lang['locfiledit_restore_confirm'] = 'Souaitez-vous charger le fichier de sauvegarde?
Vous devrez ensuite cliquer sur Enregistrer pour le restaurer.';
$lang['locfiledit_bak_loaded1'] = 'Fichier de sauvegarde chargé';
$lang['locfiledit_bak_loaded2'] = 'Vous devez l\'enregistrer pour le sauvegarder.';
$lang['locfiledit_syntax_error'] = 'Erreur de syntaxe! Impossible d\'enregistrer le fichier.';
$lang['locfiledit_new_tpl'] = 'Créer un nouveau fichier';
$lang['locfiledit_new_filename'] = 'Nom du fichier';
$lang['locfiledit_model'] = 'Modèle';
$lang['locfiledit_empty_page'] = 'Page vierge';
$lang['locfiledit_parent_directory'] = 'Dossier parent';
$lang['locfiledit_filename_error'] = 'Caractères interdits dans le nom du fichier.';
$lang['locfiledit_file_already_exists'] = 'Le fichier existe déjà.';
$lang['locfiledit_model_error'] = 'Veuillez sélectionner un modèle.';
$lang['locfiledit_empty_filename'] = 'Veuillez indiquer un nom de fichier.';
$lang['locfiledit_webmaster_only'] = 'Seuls les webmasters sont autorisés à créer ou modifier les fichiers locaux.';
?>
